@@ -19,34 +19,29 @@ def ApplyGo(self):
     elif (self.core.valCurTab == 2):
         Simple_Adjustments(self, self.core.current.image, "Any", True)
     elif (self.core.valCurTab == 3):
-        Adjust_ColorLevel(self, self.core.current.image, True)
+        Adjust_ColorLevel(self, self.core.current.image, "Any", True)
     elif (self.core.valCurTab == 4):
-        Adjust_ToneLevel(self, self.core.current.image, True)
+        Adjust_ToneLevel(self, self.core.current.image, "Any", True)
     elif (self.core.valCurTab == 5):
         RotateApply(self,  self.core.valRot)
 
     SlidersReset(self)
     FileImageRefresh(self)
+    showUpdateLabel(self, False,  False)
     ShowApply(self, False)
     ToggleThumbWait(self, False)
     
-def cSlide_ShiftValue(self, change, coreVal, qTextbox,  qSlider):
-    coreVal  = coreVal + change
-    qTextbox.setText(str(coreVal))
-    qSlider.setValue(coreVal)
-    return coreVal
-    
-def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider):
+def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider,  cSource = "Any"):
     coreVal  = value
     tab =self.core.GetCurrentTab(self)
     qTextbox.setText(str(coreVal))
     if  (self.core.displayUpdating == False):
         if (tab == 2):
-            Simple_Adjustments(self, self.core.current.thumb, "Any",  False)
+            Simple_Adjustments(self, self.core.current.thumb, cSource,  False)
         elif (tab == 3):
-            Adjust_ColorLevel(self, self.core.current.thumb,  False)
+            Adjust_ColorLevel(self, self.core.current.thumb, cSource, False)
         elif (tab == 4):
-            Adjust_ToneLevel(self, self.core.current.thumb,  False)
+            Adjust_ToneLevel(self, self.core.current.thumb,  cSource,  False)
     return coreVal
 
 def SlidersReset(self):
@@ -61,13 +56,12 @@ def SlidersReset(self):
     self.cSlide_Sa.setValue(0)
     self.cSlide_Sh.setValue(0)
     self.cSlide_Sw.setValue(0)
+    self.repaint()
     self.core.displayUpdating = False
               
-      
-    #######################################
-    #   Undo
-    #######################################
-        
+#######################################
+#   Undo
+#######################################
 def UndoGo(self):
     self.core.UndoImage_Set()
     self.loadUndoImages()
@@ -79,56 +73,3 @@ def UndoGo(self):
     self.btnApplyUndo.setText(":"+str(self.core.undoCount))
     ToggleThumbWait(self, False)
         
-        
-        
-        
-        
-        
-        
-        
-        
-        
-        
-        
-#def on_cSlide_B_sliderReleased(self):
-#    self.core.valB = value
-#    self.lcdB.setText(str(self.core.valB))
-#    self.LevelApply(self.core.current.thumb,  False)
-#        
-#def on_btnSlide_H_up_pressed(self):
-#    self.core.valB = value
-#    self.lcdB.setText(str(self.core.valB))
-#    self.LevelApply(self.core.current.thumb,  False)
-#    
-#def on_btnSlide_H_dn_pressed(self):
-#    
-#def on_btnSlide_Mid_dn_pressed(self):
-#    
-#def on_btnSlide_Mid_up_pressed(self):
-#
-#def on_btnSlide_Sha_dn_pressed(self):
-#
-#def on_btnSlide_Sha_up_pressed(self):
-#
-#def on_btnSlide_Co_dn_pressed(self):
-#
-#def on_btnSlide_Co_up_pressed(self):
-#
-#def on_btnSlide_Sa_up_pressed(self):
-#
-#def on_btnSlide_Sa_dn_pressed(self):
-#
-#def on_btnSlide_Br_dn_pressed(self):
-#
-#def on_btnSlide_Br_up_pressed(self):
-#
-#def on_btnSlide_Sh_dn_pressed(self):
-#
-#def on_btnSlide_sh_up_pressed(self):
-#
-
-
-#
-#def on_btnSlide_G_up_pressed(self):
-#
-#def on_btnSlide_G_dn_pressed(self):
