@@ -86,144 +86,207 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #   Color Sliders
     #######################################
     def on_cSlide_B_valueChanged(self, value):
-        if (self.core.valB <> value):
-            self.core.valB = cSlide_SetValue(self, value,  self.core.valB,  self.lcdB, self.cSlide_B)
-        
-    def on_btnSlide_B_up_pressed(self):
-        self.core.valB = cSlide_ShiftValue(self,  1,  self.core.valB,  self.lcdB, self.cSlide_B)
-        
+        self.core.valB = cSlide_SetValue(self, value,  self.core.valB,  self.lcdB, self.cSlide_B,  "B")
     def on_btnSlide_B_dn_pressed(self):
-        self.core.valB = cSlide_ShiftValue(self, -1,  self.core.valB,  self.lcdB, self.cSlide_B)
-
-    @pyqtSignature("int")
+        self.core.valB -= 1
+        self.cSlide_B.setValue(self.core.valB)
+    def on_btnSlide_B_up_pressed(self):
+        self.core.valB += 1
+        self.cSlide_B.setValue(self.core.valB)        
+        
     def on_cSlide_R_valueChanged(self, value):
-        """
-        Set Red Value
-        """
-        if (self.core.valR <> value):
-            self.core.valR = cSlide_SetValue(self, value,  self.core.valR,  self.lcdR, self.cSlide_R)
-        
+        self.core.valR = cSlide_SetValue(self, value,  self.core.valR,  self.lcdR, self.cSlide_R,  "R")
     def on_btnSlide_R_dn_pressed(self):
-        self.core.valR = cSlide_ShiftValue(self,  -1,  self.core.valR,  self.lcdR, self.cSlide_R)
-        
+        self.core.valR -= 1
+        self.cSlide_R.setValue(self.core.valR)
     def on_btnSlide_R_up_pressed(self):
-        self.core.valR = cSlide_ShiftValue(self, 1,  self.core.valR,  self.lcdR, self.cSlide_R)       
-    
-    @pyqtSignature("int")
+        self.core.valR += 1
+        self.cSlide_R.setValue(self.core.valR)
+        
     def on_cSlide_G_valueChanged(self, value):
-        """
-        Set Green Value
-        """
-        if (self.core.valG <> value):
-            self.core.valG = cSlide_SetValue(self, value,  self.core.valG,  self.lcdG, self.cSlide_G)
-        
-    def on_btnSlide_G_up_pressed(self):
-        self.core.valG = cSlide_ShiftValue(self,  1,  self.core.valG,  self.lcdG, self.cSlide_G)
-        
+        self.core.valG = cSlide_SetValue(self, value,  self.core.valG,  self.lcdG, self.cSlide_G,  "G")        
     def on_btnSlide_G_dn_pressed(self):
-        self.core.valG = cSlide_ShiftValue(self, -1,  self.core.valG,  self.lcdG, self.cSlide_G)
+        self.core.valG -= 1
+        self.cSlide_G.setValue(self.core.valG)
+    def on_btnSlide_G_up_pressed(self):
+        self.core.valG += 1
+        self.cSlide_G.setValue(self.core.valG)
     
 
   
     #######################################
     #   Level Applys
     #######################################
+    def on_cSlide_Hi_valueChanged(self, value):
+        self.core.valHi = cSlide_SetValue(self, value,  self.core.valHi,  self.lcdHi, self.cSlide_Hi,  "Hi")
+    def on_btnSlide_H_dn_pressed(self):
+        self.core.valHi -= 1
+        self.cSlide_Hi.setValue(self.core.valHi)
+    def on_btnSlide_H_up_pressed(self):
+        self.core.valHi += 1
+        self.cSlide_Hi.setValue(self.core.valHi)
   
     def on_cSlide_Mi_valueChanged(self, value):
-        if (self.core.valMi <> value):
-            self.core.valMi = cSlide_SetValue(self, value,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
-        
+        self.core.valMi = cSlide_SetValue(self, value,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi,  "Mi")
     def on_btnSlide_Mid_dn_pressed(self):
-        self.core.valMi= cSlide_ShiftValue(self,  -1,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
-            
+        self.core.valMi -= 1
+        self.cSlide_Mi.setValue(self.core.valMi)            
     def on_btnSlide_Mid_up_pressed(self):
-        self.core.valMi = cSlide_ShiftValue(self,  1,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
-  
-  
-    def on_cSlide_Hi_valueChanged(self, value):
-        if (self.core.valHi <> value):
-            self.core.valHi = cSlide_SetValue(self, value,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
+        self.core.valMi += 1
+        self.cSlide_Mi.setValue(self.core.valMi)
 
-    def on_btnSlide_H_dn_pressed(self):
-        self.core.valHi = cSlide_ShiftValue(self,  -1,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
-        
-    def on_btnSlide_H_up_pressed(self):
-        self.core.valHi = cSlide_ShiftValue(self,   1,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
-    
-    
     def on_cSlide_Sw_valueChanged(self, value):
-        if (self.core.valSw <> value):
-            self.core.valSw = cSlide_SetValue(self, value,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
-        
+        self.core.valSw = cSlide_SetValue(self, value,  self.core.valSw,  self.lcdSw, self.cSlide_Sw,  "Sw")        
     def on_btnSlide_Sha_dn_pressed(self):
-        self.core.valSw = cSlide_ShiftValue(self,  -1,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
-        
+        self.core.valSw -= 1
+        self.cSlide_Sw.setValue(self.core.valSw)
     def on_btnSlide_Sha_up_pressed(self):
-        self.core.valSw = cSlide_ShiftValue(self,   1,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
+        self.core.valSw += 1
+        self.cSlide_Sw.setValue(self.core.valSw)
 
-
-   
     #######################################
-    #   Level Applys
+    #   Simple Applys
     #######################################
-    
-    @pyqtSignature("int")
     def on_cSlide_Co_valueChanged(self, value):
-        if (self.core.valCo != value):
-            self.core.valCo = cSlide_SetValue(self, value,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
-        
+        self.core.valCo = cSlide_SetValue(self, value,  self.core.valCo,  self.lcdCo, self.cSlide_Co,  "Co")
     def on_btnSlide_Co_dn_pressed(self):
-        self.core.valCo = cSlide_ShiftValue(self,  -1,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
-        
+        self.core.valCo -= 1
+        self.cSlide_Co.setValue(self.core.valCo)
     def on_btnSlide_Co_up_pressed(self):
-        self.core.valCo = cSlide_ShiftValue(self,   1,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
+        self.core.valCo += 1
+        self.cSlide_Co.setValue(self.core.valCo)
     
-    
-    @pyqtSignature("int")
     def on_cSlide_Sh_valueChanged(self, value):
-        if (self.core.valSh <> value):
-            self.core.valSh = cSlide_SetValue(self, value,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
-            
+        self.core.valSh = cSlide_SetValue(self, value,  self.core.valSh,  self.lcdSh, self.cSlide_Sh,  "Sh")            
     def on_btnSlide_Sh_dn_pressed(self):
-        self.core.valSh = cSlide_ShiftValue(self,  -1,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
-        
+        self.core.valSh -= 1
+        self.cSlide_Sh.setValue(self.core.valSh)
     def on_btnSlide_sh_up_pressed(self):
-        self.core.valSh = cSlide_ShiftValue(self,   1,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
-
+        self.core.valSh += 1
+        self.cSlide_Sh.setValue(self.core.valSh)
         
-    @pyqtSignature("int")
     def on_cSlide_Sa_valueChanged(self, value):
-        if (self.core.valSa <> value):
-            self.core.valSa = cSlide_SetValue(self, value,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
-    
+        self.core.valSa = cSlide_SetValue(self, value,  self.core.valSa,  self.lcdSa, self.cSlide_Sa,  "Sa")    
     def on_btnSlide_Sa_up_pressed(self):
-        self.core.valSa = cSlide_ShiftValue(self,   1,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
-        
+        self.core.valSa += 1
+        self.cSlide_Sa.setValue(self.core.valSa)
     def on_btnSlide_Sa_dn_pressed(self):
-        self.core.valSa = cSlide_ShiftValue(self,  -1,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
-        
+        self.core.valSa -= 1
+        self.cSlide_Sa.setValue(self.core.valSa)
     
-    @pyqtSignature("int")
     def on_cSlide_Br_valueChanged(self, value):
-        if (self.core.valBr <> value):
-            self.core.valBr = cSlide_SetValue(self, value,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
-    
+        self.core.valBr = cSlide_SetValue(self, value,  self.core.valBr,  self.lcdBr, self.cSlide_Br,  "Br")
     def on_btnSlide_Br_dn_pressed(self):
-        self.core.valBr = cSlide_ShiftValue(self,  -1,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
-        
+        self.core.valBr -= 1
+        self.cSlide_Br.setValue(self.core.valBr)
     def on_btnSlide_Br_up_pressed(self):
-        self.core.valBr = cSlide_ShiftValue(self,  1,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
-        
-        
+        self.core.valBr += 1
+        self.cSlide_Br.setValue(self.core.valBr)
         
+    #######################################
+    #   B & W Settings
+    #######################################
+    def on_btn_Grey_released(self):
+        self.core.valBW = "L"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Red_released(self):
+        self.core.valBW = "R"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Green_released(self):
+        self.core.valBW = "G"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Blue_released(self):
+        self.core.valBW = "B"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Yellow_released(self):
+        self.core.valBW = "Y"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Cyan_released(self):
+        self.core.valBW = "C"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_Magenta_released(self):
+        self.core.valBW = "M"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_BC_released(self):
+        self.core.valBW = "BC"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_GC_released(self):
+        self.core.valBW = "GC"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_GY_released(self):
+        self.core.valBW = "GY"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_BM_released(self):
+        self.core.valBW = "BM"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_RM_released(self):
+        self.core.valBW = "RM"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    def on_btn_RY_released(self):
+        self.core.valBW = "RY"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+
+#######################################
+    #   Rotation
+    ####################################### 
+            
     @pyqtSignature("int")
     def on_dial_valueChanged(self, value):
-        if  (self.core.lockUpdating == False):
+        if  self.ResetRotSliders("Dial"):
             self.core.valRot = value
             self.lcdRot_1.setText(str(self.core.valRot))
             RotateThumb(self,  value)
            
+    def on_btn_rot_Vert_released(self):
+        if  self.ResetRotSliders("FlipV"):
+            self.core.flipRight = not self.core.flipRight 
+            FlipThumb(self)
+        
+    def on_btn_rot_Horz_pressed(self):
+        if   self.ResetRotSliders("FlipH"):
+            self.core.flipBottom = not self.core.flipBottom 
+            FlipThumb(self)
+        
+    def on_btn_rot_90cw_released(self):
+        if  self.ResetRotSliders("Rot"):
+            self.core.flipAng = 270
+            FlipThumb(self)
 
+    def on_btn_rot_90ccw_released(self):
+        if  self.ResetRotSliders("Rot"):
+            self.core.flipAng = 90
+            FlipThumb(self)
+        
+    def on_btn_rot_180_released(self):
+        if self.ResetRotSliders("Rot"):
+            if self.core.flipAng == 180:
+                self.core.flipAng = 0
+            else:
+                self.core.flipAng = 180
+            FlipThumb(self)
+    
+    def ResetRotSliders(self,  State):
+        if  (self.core.lockUpdating == False):
+            if State=="FlipH":
+                self.core.flipRight = False
+                self.core.flipAng = 0
+                self.dial.setValue(0)
+            if State=="FlipV":
+                self.core.flipBottom = False
+                self.core.flipAng = 0
+                self.dial.setValue(0)
+            elif State=="Rot":
+                self.dial.setValue(0)
+                self.core.flipRight =False
+                self.core.flipBottom =False
+            elif State=="Dial":    
+                self.core.flipAng = 0
+                self.core.flipRight =False
+                self.core.flipBottom =False
+            return True
+        else:
+            return False
+            
     #######################################
     #   UI Reactions
     #######################################
@@ -285,17 +348,11 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #######################################
     #  Full Screen
     #######################################
-
     def on_btnFullScreen_released(self):
-        """
-        Button handler for fullscreen  open, calls FullScreenToggle
-        """
         FullScreenToggle(self,True)
-    
 
     def on_btnFullScreenClose_released(self):
         FullScreenToggle(self,False)
-
     
     def on_tabStrip_currentChanged(self, index):
         if (index==9):
@@ -306,71 +363,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             self.PopulateEXIFData(self.core.curImageLoc)
         else:
             self.core.SetCurrentTab(self.tabStrip.currentIndex() )
-        
-    #######################################
-    #   B & W Settings
-    #######################################
-    def on_btn_Grey_released(self):
-        self.core.valBW = "L"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_Red_released(self):
-        self.core.valBW = "R"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-
-    def on_btn_Green_released(self):
-        self.core.valBW = "G"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_Blue_released(self):
-        self.core.valBW = "B"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
- 
-    def on_btn_Yellow_released(self):
-        self.core.valBW = "Y"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_Cyan_released(self):
-        self.core.valBW = "C"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_Magenta_released(self):
-        self.core.valBW = "M"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-        
-    def on_btn_BC_released(self):
-        self.core.valBW = "BC"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_GC_released(self):
-        self.core.valBW = "GC"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_GY_released(self):
-        self.core.valBW = "GY"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_BM_released(self):
-        self.core.valBW = "BM"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-        
-    def on_btn_RM_released(self):
-        self.core.valBW = "RM"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    def on_btn_RY_released(self):
-        self.core.valBW = "RY"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-
-
-    def on_btnBug_released(self):
-        """
-        Submit bug report to bugs.maemo.org
-        """ 
-        url='https://bugs.maemo.org/enter_bug.cgi?product=AnselA'
-        os.system('browser --url=%s' %url)
-
-
+            
     #######################################
     #   Photo Browser
     #######################################
@@ -472,44 +465,16 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     def on_btnUndoGo_released(self):
         UndoGo(self)
        
-        
-    #######################################
-    #   Rotation
-    #######################################    
-    def on_btn_rot_Vert_released(self):
-        self.core.flipRight = not self.core.flipRight 
-        FlipThumb(self)
-        
-    def on_btn_rot_Horz_pressed(self):
-        self.core.flipBottom = not self.core.flipBottom 
-        FlipThumb(self)
-        
-    def on_btn_rot_90cw_released(self):
-        self.core.valRot = 270
-        RotateThumb(self,  self.core.valRot)
-
-    def on_btn_rot_90ccw_released(self):
-        self.core.valRot = 90
-        RotateThumb(self,  self.core.valRot)
-        
-    def on_btn_rot_180_released(self):
-        self.core.valRot = 180
-        RotateThumb(self,  self.core.valRot)
-    
-    
-    
-    
+   
     #######################################
     #   Save As
     #######################################
     def on_btnSaveAs_released(self):
-        self.DisplaySaveAs()
-
+        DisplaySaveAs(self)
 
     def on_btnSaveAsCancel_pressed(self):
         self.frameSaveAs.setGeometry(0, 40, 0, 480)
-    
-        
+       
     def on_btnSaveAsGo_pressed(self):
         WaitOverlay(self,"Saving File...")
         self.frameSaveAs.setGeometry(0, 40, 0, 480)
@@ -522,8 +487,6 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         finally:
             WaitOverlayOk(self,"Save Completed")
         
-        
-        
     def btnSaveAsFilenameString(self):
         return str(self.btnSaveAs_Location.text())+"/"+str(self.btnSaveAs_Filename.text())+"."+str(self.btnSaveAs_Combo.currentText())
         
@@ -561,7 +524,6 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             self.frameSaveAvd.setVisible(False)
             self.frameSaveAuto.setVisible(True)
 
-
     def on_btnPopWaitOk_pressed(self):
         WaitOverlayHide(self,)
         
@@ -575,17 +537,13 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     def on_btnRefreshExp_pressed(self):
         if (str(self.btnRefreshExp.text()) =="+"):
             self.btnRefreshExp.setText("-")
-            self.btnReloadPList.setGeometry(QtCore.QRect(400, 370, 111, 51))
-            self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 51))
-            self.btnRefresh.setGeometry(QtCore.QRect(250, 370, 151, 51))
+            self.btnReloadPList.setGeometry(QtCore.QRect(350, 370, 101, 51))
+            self.btnOpen.setGeometry(QtCore.QRect(450, 370, 111, 51))
+            self.btnRefresh.setGeometry(QtCore.QRect(200, 370, 151, 51))
         else:
             self.btnRefreshExp.setText("+")
             self.btnReloadPList.setGeometry(QtCore.QRect(400, 370, 111, 0))
-            self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 0))
-            self.btnRefresh.setGeometry(QtCore.QRect(250, 370, 151, 0))
-    
-    def on_btnPopMinimize_pressed(self):
-        ui.showMinimized()
+            self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 0)) 
     
     def on_SearchPhoto_Mcc_toggled(self, checked):
         if (checked):
@@ -593,6 +551,19 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         else:
             SetConfig_SearchSettings(self, 0)
     
-    @pyqtSignature("")
     def on_btnSaveSettings_pressed(self):
         WriteConfig(self)
+
+    #######################################
+    #   Web Buttons
+    #######################################
+    def on_btnBlog_pressed(self):
+        url='http://ansel-a.blogspot.com/'
+        os.system('browser --url=%s' %url)
+        
+    def on_btnBug_released(self):
+        url='https://bugs.maemo.org/enter_bug.cgi?product=AnselA'
+        os.system('browser --url=%s' %url)
+
+    def on_btnPopMinimize_released(self):
+         ui.hide()
